@@ -23,7 +23,8 @@
 #    if((getOption("StartupBanner")=="complete")||is.null(getOption("StartupBanner"))) 
 #       message(msga,msgb,sep=""); 
 buildStartupMessage(pkg="distrEx", library=library, packageHelp=TRUE, 
-                    MANUAL="http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/distr.pdf")
+#                    MANUAL="http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/distr.pdf",
+                    VIGNETTE=gettext("Package \"distrDoc\" provides a vignette to this package as well as\nto several related packages; try vignette(\"distr\")."))
 
 ###
   invisible()
